.. _api:

This section expands on the technical details of Protean's building blocks.

.. toctree::
    :maxdepth: 1
    :glob:

    domain-elements/index
    implementations/index
    config
    utils
